@@ -5,7 +5,7 @@
 %%
 %% %CopyrightBegin%
 %%
-%% Copyright Ericsson AB 1996-2017. All Rights Reserved.
+%% Copyright Ericsson AB 1996-2018. All Rights Reserved.
 %%
 %% Licensed under the Apache License, Version 2.0 (the "License");
 %% you may not use this file except in compliance with the License.
@@ -29,15 +29,15 @@
 
 -spec parse(Tokens :: list()) -> yecc_ret().
 parse(Tokens) ->
-    yeccpars0(Tokens, {no_func, no_line}, 0, [], []).
+    yeccpars0(Tokens, {no_func, no_location}, 0, [], []).
 
 -spec parse_and_scan({function() | {atom(), atom()}, [_]}
                      | {atom(), atom(), [_]}) -> yecc_ret().
 parse_and_scan({F, A}) ->
-    yeccpars0([], {{F, A}, no_line}, 0, [], []);
+    yeccpars0([], {{F, A}, no_location}, 0, [], []);
 parse_and_scan({M, F, A}) ->
     Arity = length(A),
-    yeccpars0([], {{fun M:F/Arity, A}, no_line}, 0, [], []).
+    yeccpars0([], {{fun M:F/Arity, A}, no_location}, 0, [], []).
 
 -spec format_error(any()) -> [char() | list()].
 format_error(Message) ->
@@ -51,17 +51,16 @@ format_error(Message) ->
 %% To be used in grammar files to throw an error message to the parser
 %% toplevel. Doesn't have to be exported!
 -compile({nowarn_unused_function, return_error/2}).
--spec return_error(integer(), any()) -> no_return().
-return_error(Line, Message) ->
-    throw({error, {Line, ?MODULE, Message}}).
+-spec return_error(erl_anno:location(), any()) -> no_return().
+return_error(Location, Message) ->
+    throw({error, {Location, ?MODULE, Message}}).
 
 -define(CODE_VERSION, "1.4").
 
 yeccpars0(Tokens, Tzr, State, States, Vstack) ->
     try yeccpars1(Tokens, Tzr, State, States, Vstack)
     catch 
-        error: Error ->
-            Stacktrace = erlang:get_stacktrace(),
+        error: Error: Stacktrace ->
             try yecc_error_type(Error, Stacktrace) of
                 Desc ->
                     erlang:raise(error, {yecc_bug, ?CODE_VERSION, Desc},
@@ -69,7 +68,7 @@ yeccpars0(Tokens, Tzr, State, States, Vstack) ->
             catch _:_ -> erlang:raise(error, Error, Stacktrace)
             end;
         %% Probably thrown from return_error/2:
-        throw: {error, {_Line, ?MODULE, _M}} = Error ->
+        throw: {error, {_Location, ?MODULE, _M}} = Error ->
             Error
     end.
 
@@ -86,22 +85,22 @@ yecc_error_type(function_clause, [{?MODULE,F,ArityOrArgs,_} | _]) ->
 
 yeccpars1([Token | Tokens], Tzr, State, States, Vstack) ->
     yeccpars2(State, element(1, Token), States, Vstack, Token, Tokens, Tzr);
-yeccpars1([], {{F, A},_Line}, State, States, Vstack) ->
+yeccpars1([], {{F, A},_Location}, State, States, Vstack) ->
     case apply(F, A) of
-        {ok, Tokens, Endline} ->
-            yeccpars1(Tokens, {{F, A}, Endline}, State, States, Vstack);
-        {eof, Endline} ->
-            yeccpars1([], {no_func, Endline}, State, States, Vstack);
-        {error, Descriptor, _Endline} ->
+        {ok, Tokens, EndLocation} ->
+            yeccpars1(Tokens, {{F, A}, EndLocation}, State, States, Vstack);
+        {eof, EndLocation} ->
+            yeccpars1([], {no_func, EndLocation}, State, States, Vstack);
+        {error, Descriptor, _EndLocation} ->
             {error, Descriptor}
     end;
-yeccpars1([], {no_func, no_line}, State, States, Vstack) ->
+yeccpars1([], {no_func, no_location}, State, States, Vstack) ->
     Line = 999999,
     yeccpars2(State, '$end', States, Vstack, yecc_end(Line), [],
               {no_func, Line});
-yeccpars1([], {no_func, Endline}, State, States, Vstack) ->
-    yeccpars2(State, '$end', States, Vstack, yecc_end(Endline), [],
-              {no_func, Endline}).
+yeccpars1([], {no_func, EndLocation}, State, States, Vstack) ->
+    yeccpars2(State, '$end', States, Vstack, yecc_end(EndLocation), [],
+              {no_func, EndLocation}).
 
 %% yeccpars1/7 is called from generated code.
 %%
@@ -112,21 +111,19 @@ yeccpars1([], {no_func, Endline}, State, States, Vstack) ->
 yeccpars1(State1, State, States, Vstack, Token0, [Token | Tokens], Tzr) ->
     yeccpars2(State, element(1, Token), [State1 | States],
               [Token0 | Vstack], Token, Tokens, Tzr);
-yeccpars1(State1, State, States, Vstack, Token0, [], {{_F,_A}, _Line}=Tzr) ->
+yeccpars1(State1, State, States, Vstack, Token0, [], {{_F,_A}, _Location}=Tzr) ->
     yeccpars1([], Tzr, State, [State1 | States], [Token0 | Vstack]);
-yeccpars1(State1, State, States, Vstack, Token0, [], {no_func, no_line}) ->
-    Line = yecctoken_end_location(Token0),
+yeccpars1(State1, State, States, Vstack, Token0, [], {no_func, no_location}) ->
+    Location = yecctoken_end_location(Token0),
     yeccpars2(State, '$end', [State1 | States], [Token0 | Vstack],
-              yecc_end(Line), [], {no_func, Line});
-yeccpars1(State1, State, States, Vstack, Token0, [], {no_func, Line}) ->
+              yecc_end(Location), [], {no_func, Location});
+yeccpars1(State1, State, States, Vstack, Token0, [], {no_func, Location}) ->
     yeccpars2(State, '$end', [State1 | States], [Token0 | Vstack],
-              yecc_end(Line), [], {no_func, Line}).
+              yecc_end(Location), [], {no_func, Location}).
 
 %% For internal use only.
-yecc_end({Line,_Column}) ->
-    {'$end', Line};
-yecc_end(Line) ->
-    {'$end', Line}.
+yecc_end(Location) ->
+    {'$end', Location}.
 
 yecctoken_end_location(Token) ->
     try erl_anno:end_location(element(2, Token)) of
@@ -174,7 +171,7 @@ yecctoken2string(Other) ->
 
 
 
--file("gen/diameter_dict_parser.erl", 177).
+-file("gen/diameter_dict_parser.erl", 174).
 
 -dialyzer({nowarn_function, yeccpars2/7}).
 yeccpars2(0=S, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -475,7 +472,8 @@ yeccpars2_0(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_1(_S, Cat, [0 | Ss], NewStack, T, Ts, Tzr).
 
 yeccpars2_1(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
- yeccgoto_dictionary(hd(Ss), Cat, Ss, Stack, T, Ts, Tzr).
+ NewStack = yeccpars2_1_(Stack),
+ yeccgoto_dictionary(hd(Ss), Cat, Ss, NewStack, T, Ts, Tzr).
 
 yeccpars2_2(S, avp_types, Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 4, Ss, Stack, T, Ts, Tzr);
@@ -577,7 +575,8 @@ yeccpars2_18(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccgoto_section(hd(Nss), Cat, Nss, NewStack, T, Ts, Tzr).
 
 yeccpars2_19(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
- yeccgoto_ident(hd(Ss), Cat, Ss, Stack, T, Ts, Tzr).
+ NewStack = yeccpars2_19_(Stack),
+ yeccgoto_ident(hd(Ss), Cat, Ss, NewStack, T, Ts, Tzr).
 
 yeccpars2_20(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  [_|Nss] = Ss,
@@ -595,7 +594,8 @@ yeccpars2_22(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccgoto_section(hd(Nss), Cat, Nss, NewStack, T, Ts, Tzr).
 
 yeccpars2_23(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
- yeccgoto_diameter_name(hd(Ss), Cat, Ss, Stack, T, Ts, Tzr).
+ NewStack = yeccpars2_23_(Stack),
+ yeccgoto_diameter_name(hd(Ss), Cat, Ss, NewStack, T, Ts, Tzr).
 
 -dialyzer({nowarn_function, yeccpars2_24/7}).
 yeccpars2_24(S, '::=', Ss, Stack, T, Ts, Tzr) ->
@@ -766,10 +766,12 @@ yeccpars2_48(_, _, _, _, T, _, _) ->
 %% yeccpars2_49: see yeccpars2_47
 
 yeccpars2_50(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
- yeccgoto_avp_spec(hd(Ss), Cat, Ss, Stack, T, Ts, Tzr).
+ NewStack = yeccpars2_50_(Stack),
+ yeccgoto_avp_spec(hd(Ss), Cat, Ss, NewStack, T, Ts, Tzr).
 
 yeccpars2_51(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
- yeccgoto_avp_name(hd(Ss), Cat, Ss, Stack, T, Ts, Tzr).
+ NewStack = yeccpars2_51_(Stack),
+ yeccgoto_avp_name(hd(Ss), Cat, Ss, NewStack, T, Ts, Tzr).
 
 -dialyzer({nowarn_function, yeccpars2_52/7}).
 yeccpars2_52(S, '}', Ss, Stack, T, Ts, Tzr) ->
@@ -778,7 +780,8 @@ yeccpars2_52(_, _, _, _, T, _, _) ->
  yeccerror(T).
 
 yeccpars2_53(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
- yeccgoto_avp_name(hd(Ss), Cat, Ss, Stack, T, Ts, Tzr).
+ NewStack = yeccpars2_53_(Stack),
+ yeccgoto_avp_name(hd(Ss), Cat, Ss, NewStack, T, Ts, Tzr).
 
 yeccpars2_54(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  [_,_|Nss] = Ss,
@@ -880,7 +883,8 @@ yeccpars2_70(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_72(72, Cat, [70 | Ss], NewStack, T, Ts, Tzr).
 
 yeccpars2_71(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
- yeccgoto_command_id(hd(Ss), Cat, Ss, Stack, T, Ts, Tzr).
+ NewStack = yeccpars2_71_(Stack),
+ yeccgoto_command_id(hd(Ss), Cat, Ss, NewStack, T, Ts, Tzr).
 
 yeccpars2_72(S, number, Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 79, Ss, Stack, T, Ts, Tzr);
@@ -903,10 +907,12 @@ yeccpars2_74(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_77(_S, Cat, [74 | Ss], NewStack, T, Ts, Tzr).
 
 yeccpars2_75(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
- yeccgoto_bit(hd(Ss), Cat, Ss, Stack, T, Ts, Tzr).
+ NewStack = yeccpars2_75_(Stack),
+ yeccgoto_bit(hd(Ss), Cat, Ss, NewStack, T, Ts, Tzr).
 
 yeccpars2_76(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
- yeccgoto_bit(hd(Ss), Cat, Ss, Stack, T, Ts, Tzr).
+ NewStack = yeccpars2_76_(Stack),
+ yeccgoto_bit(hd(Ss), Cat, Ss, NewStack, T, Ts, Tzr).
 
 yeccpars2_77(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  [_,_|Nss] = Ss,
@@ -920,7 +926,8 @@ yeccpars2_78(_, _, _, _, T, _, _) ->
  yeccerror(T).
 
 yeccpars2_79(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
- yeccgoto_application_id(hd(Ss), Cat, Ss, Stack, T, Ts, Tzr).
+ NewStack = yeccpars2_79_(Stack),
+ yeccgoto_application_id(hd(Ss), Cat, Ss, NewStack, T, Ts, Tzr).
 
 yeccpars2_80(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  [_,_,_,_,_,_|Nss] = Ss,
@@ -939,10 +946,12 @@ yeccpars2_82(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_84(_S, Cat, [82 | Ss], NewStack, T, Ts, Tzr).
 
 yeccpars2_83(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
- yeccgoto_module(hd(Ss), Cat, Ss, Stack, T, Ts, Tzr).
+ NewStack = yeccpars2_83_(Stack),
+ yeccgoto_module(hd(Ss), Cat, Ss, NewStack, T, Ts, Tzr).
 
 yeccpars2_84(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
- yeccgoto_avp_names(hd(Ss), Cat, Ss, Stack, T, Ts, Tzr).
+ NewStack = yeccpars2_84_(Stack),
+ yeccgoto_avp_names(hd(Ss), Cat, Ss, NewStack, T, Ts, Tzr).
 
 yeccpars2_85(S, word, Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 19, Ss, Stack, T, Ts, Tzr);
@@ -1049,7 +1058,8 @@ yeccpars2_101(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_103(103, Cat, [101 | Ss], NewStack, T, Ts, Tzr).
 
 yeccpars2_102(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
- yeccgoto_avp_code(hd(Ss), Cat, Ss, Stack, T, Ts, Tzr).
+ NewStack = yeccpars2_102_(Stack),
+ yeccgoto_avp_code(hd(Ss), Cat, Ss, NewStack, T, Ts, Tzr).
 
 -dialyzer({nowarn_function, yeccpars2_103/7}).
 yeccpars2_103(S, '>', Ss, Stack, T, Ts, Tzr) ->
@@ -1058,7 +1068,8 @@ yeccpars2_103(_, _, _, _, T, _, _) ->
  yeccerror(T).
 
 yeccpars2_104(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
- yeccgoto_avp_vendor(hd(Ss), Cat, Ss, Stack, T, Ts, Tzr).
+ NewStack = yeccpars2_104_(Stack),
+ yeccgoto_avp_vendor(hd(Ss), Cat, Ss, NewStack, T, Ts, Tzr).
 
 yeccpars2_105(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  [_,_,_,_,_|Nss] = Ss,
@@ -1172,7 +1183,8 @@ yeccpars2_124(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 %% yeccpars2_125: see yeccpars2_6
 
 yeccpars2_126(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
- yeccgoto_avp_type(hd(Ss), Cat, Ss, Stack, T, Ts, Tzr).
+ NewStack = yeccpars2_126_(Stack),
+ yeccgoto_avp_type(hd(Ss), Cat, Ss, NewStack, T, Ts, Tzr).
 
 -dialyzer({nowarn_function, yeccpars2_127/7}).
 yeccpars2_127(S, '-', Ss, Stack, T, Ts, Tzr) ->
@@ -1183,7 +1195,8 @@ yeccpars2_127(_, _, _, _, T, _, _) ->
  yeccerror(T).
 
 yeccpars2_128(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
- yeccgoto_avp_flags(hd(Ss), Cat, Ss, Stack, T, Ts, Tzr).
+ NewStack = yeccpars2_128_(Stack),
+ yeccgoto_avp_flags(hd(Ss), Cat, Ss, NewStack, T, Ts, Tzr).
 
 yeccpars2_129(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  [_,_,_|Nss] = Ss,
@@ -1477,505 +1490,635 @@ yeccgoto_sections(2=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 -file("compiler/diameter_dict_parser.yrl", 48).
 yeccpars2_0_(__Stack0) ->
  [begin
-   [ ]
+                               []
   end | __Stack0].
 
+-compile({inline,yeccpars2_1_/1}).
+-file("compiler/diameter_dict_parser.yrl", 46).
+yeccpars2_1_(__Stack0) ->
+ [___1 | __Stack] = __Stack0,
+ [begin
+                         ___1
+  end | __Stack].
+
 -compile({inline,yeccpars2_2_/1}).
 -file("compiler/diameter_dict_parser.yrl", 48).
 yeccpars2_2_(__Stack0) ->
  [begin
-   [ ]
+                               []
   end | __Stack0].
 
 -compile({inline,yeccpars2_4_/1}).
 -file("compiler/diameter_dict_parser.yrl", 71).
 yeccpars2_4_(__Stack0) ->
  [begin
-   [ ]
+                               []
   end | __Stack0].
 
 -compile({inline,yeccpars2_10_/1}).
 -file("compiler/diameter_dict_parser.yrl", 97).
 yeccpars2_10_(__Stack0) ->
  [begin
-   [ ]
+                                     []
   end | __Stack0].
 
 -compile({inline,yeccpars2_13_/1}).
 -file("compiler/diameter_dict_parser.yrl", 100).
 yeccpars2_13_(__Stack0) ->
  [begin
-   [ ]
+                                           []
   end | __Stack0].
 
 -compile({inline,yeccpars2_18_/1}).
 -file("compiler/diameter_dict_parser.yrl", 54).
 yeccpars2_18_(__Stack0) ->
- [__3,__2,__1 | __Stack] = __Stack0,
+ [___3,___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 , __2 , __3 ]
+                                       [___1, ___2, ___3]
+  end | __Stack].
+
+-compile({inline,yeccpars2_19_/1}).
+-file("compiler/diameter_dict_parser.yrl", 90).
+yeccpars2_19_(__Stack0) ->
+ [___1 | __Stack] = __Stack0,
+ [begin
+                ___1
   end | __Stack].
 
 -compile({inline,yeccpars2_20_/1}).
 -file("compiler/diameter_dict_parser.yrl", 52).
 yeccpars2_20_(__Stack0) ->
- [__2,__1 | __Stack] = __Stack0,
+ [___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 , __2 ]
+                          [___1, ___2]
   end | __Stack].
 
 -compile({inline,yeccpars2_21_/1}).
 -file("compiler/diameter_dict_parser.yrl", 51).
 yeccpars2_21_(__Stack0) ->
- [__2,__1 | __Stack] = __Stack0,
+ [___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 , __2 ]
+                          [___1, ___2]
   end | __Stack].
 
 -compile({inline,yeccpars2_22_/1}).
 -file("compiler/diameter_dict_parser.yrl", 60).
 yeccpars2_22_(__Stack0) ->
- [__2,__1 | __Stack] = __Stack0,
+ [___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 | __2 ]
+                                    [___1 | ___2]
+  end | __Stack].
+
+-compile({inline,yeccpars2_23_/1}).
+-file("compiler/diameter_dict_parser.yrl", 137).
+yeccpars2_23_(__Stack0) ->
+ [___1 | __Stack] = __Stack0,
+ [begin
+                         ___1
   end | __Stack].
 
 -compile({inline,yeccpars2_25_/1}).
 -file("compiler/diameter_dict_parser.yrl", 100).
 yeccpars2_25_(__Stack0) ->
  [begin
-   [ ]
+                                           []
   end | __Stack0].
 
 -compile({inline,yeccpars2_31_/1}).
 -file("compiler/diameter_dict_parser.yrl", 0).
 yeccpars2_31_(__Stack0) ->
- [__1 | __Stack] = __Stack0,
+ [___1 | __Stack] = __Stack0,
  [begin
-   '$undefined'
+'$undefined'
   end | __Stack].
 
 -compile({inline,yeccpars2_32_/1}).
 -file("compiler/diameter_dict_parser.yrl", 0).
 yeccpars2_32_(__Stack0) ->
- [__2,__1 | __Stack] = __Stack0,
+ [___2,___1 | __Stack] = __Stack0,
  [begin
-   '$undefined'
+'$undefined'
   end | __Stack].
 
 -compile({inline,yeccpars2_40_/1}).
 -file("compiler/diameter_dict_parser.yrl", 203).
 yeccpars2_40_(__Stack0) ->
  [begin
-   [ ]
+                   []
   end | __Stack0].
 
 -compile({inline,yeccpars2_42_/1}).
 -file("compiler/diameter_dict_parser.yrl", 128).
 yeccpars2_42_(__Stack0) ->
- [__13,__12,__11,__10,__9,__8,__7,__6,__5,__4,__3,__2,__1 | __Stack] = __Stack0,
+ [___13,___12,___11,___10,___9,___8,___7,___6,___5,___4,___3,___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 , false | __13 ]
+    [___1, false | ___13]
   end | __Stack].
 
 -compile({inline,yeccpars2_43_/1}).
 -file("compiler/diameter_dict_parser.yrl", 206).
 yeccpars2_43_(__Stack0) ->
- [__1 | __Stack] = __Stack0,
+ [___1 | __Stack] = __Stack0,
  [begin
-   [ false | __1 ]
+                      [false | ___1]
   end | __Stack].
 
 -compile({inline,yeccpars2_44_/1}).
 -file("compiler/diameter_dict_parser.yrl", 203).
 yeccpars2_44_(__Stack0) ->
  [begin
-   [ ]
+                   []
   end | __Stack0].
 
 -compile({inline,yeccpars2_45_/1}).
 -file("compiler/diameter_dict_parser.yrl", 242).
 yeccpars2_45_(__Stack0) ->
- [__1 | __Stack] = __Stack0,
+ [___1 | __Stack] = __Stack0,
  [begin
-   true
+                            true
+  end | __Stack].
+
+-compile({inline,yeccpars2_50_/1}).
+-file("compiler/diameter_dict_parser.yrl", 249).
+yeccpars2_50_(__Stack0) ->
+ [___1 | __Stack] = __Stack0,
+ [begin
+                            ___1
+  end | __Stack].
+
+-compile({inline,yeccpars2_51_/1}).
+-file("compiler/diameter_dict_parser.yrl", 258).
+yeccpars2_51_(__Stack0) ->
+ [___1 | __Stack] = __Stack0,
+ [begin
+                       ___1
+  end | __Stack].
+
+-compile({inline,yeccpars2_53_/1}).
+-file("compiler/diameter_dict_parser.yrl", 257).
+yeccpars2_53_(__Stack0) ->
+ [___1 | __Stack] = __Stack0,
+ [begin
+                       ___1
   end | __Stack].
 
 -compile({inline,yeccpars2_54_/1}).
 -file("compiler/diameter_dict_parser.yrl", 210).
 yeccpars2_54_(__Stack0) ->
- [__3,__2,__1 | __Stack] = __Stack0,
+ [___3,___2,___1 | __Stack] = __Stack0,
  [begin
-   [ 123 , __2 ]
+                              [${, ___2]
   end | __Stack].
 
 -compile({inline,yeccpars2_55_/1}).
 -file("compiler/diameter_dict_parser.yrl", 240).
 yeccpars2_55_(__Stack0) ->
- [__2,__1 | __Stack] = __Stack0,
+ [___2,___1 | __Stack] = __Stack0,
  [begin
-   { __1 , true }
+                            {___1, true}
   end | __Stack].
 
 -compile({inline,yeccpars2_56_/1}).
 -file("compiler/diameter_dict_parser.yrl", 239).
 yeccpars2_56_(__Stack0) ->
- [__3,__2,__1 | __Stack] = __Stack0,
+ [___3,___2,___1 | __Stack] = __Stack0,
  [begin
-   { __1 , __3 }
+                            {___1, ___3}
   end | __Stack].
 
 -compile({inline,yeccpars2_58_/1}).
 -file("compiler/diameter_dict_parser.yrl", 211).
 yeccpars2_58_(__Stack0) ->
- [__3,__2,__1 | __Stack] = __Stack0,
+ [___3,___2,___1 | __Stack] = __Stack0,
  [begin
-   [ 91 , __2 ]
+                              [$[, ___2]
   end | __Stack].
 
 -compile({inline,yeccpars2_60_/1}).
 -file("compiler/diameter_dict_parser.yrl", 209).
 yeccpars2_60_(__Stack0) ->
- [__3,__2,__1 | __Stack] = __Stack0,
+ [___3,___2,___1 | __Stack] = __Stack0,
  [begin
-   [ 60 , __2 ]
+                              [$<, ___2]
   end | __Stack].
 
 -compile({inline,yeccpars2_61_/1}).
 -file("compiler/diameter_dict_parser.yrl", 241).
 yeccpars2_61_(__Stack0) ->
- [__2,__1 | __Stack] = __Stack0,
+ [___2,___1 | __Stack] = __Stack0,
  [begin
-   { true , __2 }
+                            {true, ___2}
   end | __Stack].
 
 -compile({inline,yeccpars2_62_/1}).
 -file("compiler/diameter_dict_parser.yrl", 204).
 yeccpars2_62_(__Stack0) ->
- [__2,__1 | __Stack] = __Stack0,
+ [___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 | __2 ]
+                   [___1 | ___2]
   end | __Stack].
 
 -compile({inline,yeccpars2_63_/1}).
 -file("compiler/diameter_dict_parser.yrl", 207).
 yeccpars2_63_(__Stack0) ->
- [__2,__1 | __Stack] = __Stack0,
+ [___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 | __2 ]
+                      [___1 | ___2]
   end | __Stack].
 
 -compile({inline,yeccpars2_64_/1}).
 -file("compiler/diameter_dict_parser.yrl", 101).
 yeccpars2_64_(__Stack0) ->
- [__2,__1 | __Stack] = __Stack0,
+ [___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 | __2 ]
+                                           [___1 | ___2]
   end | __Stack].
 
 -compile({inline,yeccpars2_66_/1}).
 -file("compiler/diameter_dict_parser.yrl", 203).
 yeccpars2_66_(__Stack0) ->
  [begin
-   [ ]
+                   []
   end | __Stack0].
 
 -compile({inline,yeccpars2_70_/1}).
 -file("compiler/diameter_dict_parser.yrl", 173).
 yeccpars2_70_(__Stack0) ->
  [begin
-   [ ]
+                       []
   end | __Stack0].
 
+-compile({inline,yeccpars2_71_/1}).
+-file("compiler/diameter_dict_parser.yrl", 166).
+yeccpars2_71_(__Stack0) ->
+ [___1 | __Stack] = __Stack0,
+ [begin
+                       ___1
+  end | __Stack].
+
 -compile({inline,yeccpars2_72_/1}).
 -file("compiler/diameter_dict_parser.yrl", 181).
 yeccpars2_72_(__Stack0) ->
  [begin
-   false
+                             false
   end | __Stack0].
 
 -compile({inline,yeccpars2_74_/1}).
 -file("compiler/diameter_dict_parser.yrl", 173).
 yeccpars2_74_(__Stack0) ->
  [begin
-   [ ]
+                       []
   end | __Stack0].
 
+-compile({inline,yeccpars2_75_/1}).
+-file("compiler/diameter_dict_parser.yrl", 179).
+yeccpars2_75_(__Stack0) ->
+ [___1 | __Stack] = __Stack0,
+ [begin
+               ___1
+  end | __Stack].
+
+-compile({inline,yeccpars2_76_/1}).
+-file("compiler/diameter_dict_parser.yrl", 178).
+yeccpars2_76_(__Stack0) ->
+ [___1 | __Stack] = __Stack0,
+ [begin
+               ___1
+  end | __Stack].
+
 -compile({inline,yeccpars2_77_/1}).
 -file("compiler/diameter_dict_parser.yrl", 174).
 yeccpars2_77_(__Stack0) ->
- [__3,__2,__1 | __Stack] = __Stack0,
+ [___3,___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __2 | __3 ]
+                       [___2 | ___3]
+  end | __Stack].
+
+-compile({inline,yeccpars2_79_/1}).
+-file("compiler/diameter_dict_parser.yrl", 182).
+yeccpars2_79_(__Stack0) ->
+ [___1 | __Stack] = __Stack0,
+ [begin
+                             ___1
   end | __Stack].
 
 -compile({inline,yeccpars2_80_/1}).
 -file("compiler/diameter_dict_parser.yrl", 164).
 yeccpars2_80_(__Stack0) ->
- [__7,__6,__5,__4,__3,__2,__1 | __Stack] = __Stack0,
+ [___7,___6,___5,___4,___3,___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __4 , __5 , __6 ]
+    [___4, ___5, ___6]
   end | __Stack].
 
 -compile({inline,yeccpars2_81_/1}).
 -file("compiler/diameter_dict_parser.yrl", 131).
 yeccpars2_81_(__Stack0) ->
- [__4,__3,__2,__1 | __Stack] = __Stack0,
+ [___4,___3,___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 , __3 | __4 ]
+    [___1, ___3 | ___4]
   end | __Stack].
 
 -compile({inline,yeccpars2_82_/1}).
 -file("compiler/diameter_dict_parser.yrl", 78).
 yeccpars2_82_(__Stack0) ->
  [begin
-   [ ]
+                         []
   end | __Stack0].
 
+-compile({inline,yeccpars2_83_/1}).
+-file("compiler/diameter_dict_parser.yrl", 67).
+yeccpars2_83_(__Stack0) ->
+ [___1 | __Stack] = __Stack0,
+ [begin
+                  ___1
+  end | __Stack].
+
+-compile({inline,yeccpars2_84_/1}).
+-file("compiler/diameter_dict_parser.yrl", 69).
+yeccpars2_84_(__Stack0) ->
+ [___1 | __Stack] = __Stack0,
+ [begin
+                      ___1
+  end | __Stack].
+
 -compile({inline,yeccpars2_85_/1}).
 -file("compiler/diameter_dict_parser.yrl", 78).
 yeccpars2_85_(__Stack0) ->
  [begin
-   [ ]
+                         []
   end | __Stack0].
 
 -compile({inline,yeccpars2_86_/1}).
 -file("compiler/diameter_dict_parser.yrl", 55).
 yeccpars2_86_(__Stack0) ->
- [__3,__2,__1 | __Stack] = __Stack0,
+ [___3,___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 , __2 | __3 ]
+                                       [___1, ___2 | ___3]
   end | __Stack].
 
 -compile({inline,yeccpars2_87_/1}).
 -file("compiler/diameter_dict_parser.yrl", 79).
 yeccpars2_87_(__Stack0) ->
- [__2,__1 | __Stack] = __Stack0,
+ [___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 | __2 ]
+                         [___1 | ___2]
   end | __Stack].
 
 -compile({inline,yeccpars2_88_/1}).
 -file("compiler/diameter_dict_parser.yrl", 53).
 yeccpars2_88_(__Stack0) ->
- [__2,__1 | __Stack] = __Stack0,
+ [___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 , __2 ]
+                          [___1, ___2]
   end | __Stack].
 
 -compile({inline,yeccpars2_90_/1}).
 -file("compiler/diameter_dict_parser.yrl", 61).
 yeccpars2_90_(__Stack0) ->
- [__2,__1 | __Stack] = __Stack0,
+ [___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 | __2 ]
+                                    [___1 | ___2]
   end | __Stack].
 
 -compile({inline,yeccpars2_91_/1}).
 -file("compiler/diameter_dict_parser.yrl", 97).
 yeccpars2_91_(__Stack0) ->
  [begin
-   [ ]
+                                     []
   end | __Stack0].
 
 -compile({inline,yeccpars2_92_/1}).
 -file("compiler/diameter_dict_parser.yrl", 98).
 yeccpars2_92_(__Stack0) ->
- [__2,__1 | __Stack] = __Stack0,
+ [___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 | __2 ]
+                                     [___1 | ___2]
   end | __Stack].
 
 -compile({inline,yeccpars2_94_/1}).
 -file("compiler/diameter_dict_parser.yrl", 203).
 yeccpars2_94_(__Stack0) ->
  [begin
-   [ ]
+                   []
   end | __Stack0].
 
 -compile({inline,yeccpars2_98_/1}).
 -file("compiler/diameter_dict_parser.yrl", 0).
 yeccpars2_98_(__Stack0) ->
- [__1 | __Stack] = __Stack0,
+ [___1 | __Stack] = __Stack0,
  [begin
-   '$undefined'
+'$undefined'
   end | __Stack].
 
 -compile({inline,yeccpars2_99_/1}).
 -file("compiler/diameter_dict_parser.yrl", 0).
 yeccpars2_99_(__Stack0) ->
- [__2,__1 | __Stack] = __Stack0,
+ [___2,___1 | __Stack] = __Stack0,
  [begin
-   '$undefined'
+'$undefined'
   end | __Stack].
 
 -compile({inline,yeccpars2_101_/1}).
 -file("compiler/diameter_dict_parser.yrl", 320).
 yeccpars2_101_(__Stack0) ->
  [begin
-   false
+                         false
   end | __Stack0].
 
+-compile({inline,yeccpars2_102_/1}).
+-file("compiler/diameter_dict_parser.yrl", 318).
+yeccpars2_102_(__Stack0) ->
+ [___1 | __Stack] = __Stack0,
+ [begin
+                     ___1
+  end | __Stack].
+
+-compile({inline,yeccpars2_104_/1}).
+-file("compiler/diameter_dict_parser.yrl", 321).
+yeccpars2_104_(__Stack0) ->
+ [___1 | __Stack] = __Stack0,
+ [begin
+                         ___1
+  end | __Stack].
+
 -compile({inline,yeccpars2_105_/1}).
 -file("compiler/diameter_dict_parser.yrl", 313).
 yeccpars2_105_(__Stack0) ->
- [__6,__5,__4,__3,__2,__1 | __Stack] = __Stack0,
+ [___6,___5,___4,___3,___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __4 , __5 ]
+    [___4, ___5]
   end | __Stack].
 
 -compile({inline,yeccpars2_106_/1}).
 -file("compiler/diameter_dict_parser.yrl", 300).
 yeccpars2_106_(__Stack0) ->
- [__4,__3,__2,__1 | __Stack] = __Stack0,
+ [___4,___3,___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 , __3 | __4 ]
+                                           [___1, ___3 | ___4]
   end | __Stack].
 
 -compile({inline,yeccpars2_107_/1}).
 -file("compiler/diameter_dict_parser.yrl", 103).
 yeccpars2_107_(__Stack0) ->
  [begin
-   [ ]
+                                  []
   end | __Stack0].
 
 -compile({inline,yeccpars2_109_/1}).
 -file("compiler/diameter_dict_parser.yrl", 62).
 yeccpars2_109_(__Stack0) ->
- [__3,__2,__1 | __Stack] = __Stack0,
+ [___3,___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 , __2 | __3 ]
+                                    [___1, ___2 | ___3]
   end | __Stack].
 
 -compile({inline,yeccpars2_110_/1}).
 -file("compiler/diameter_dict_parser.yrl", 103).
 yeccpars2_110_(__Stack0) ->
  [begin
-   [ ]
+                                  []
   end | __Stack0].
 
 -compile({inline,yeccpars2_111_/1}).
 -file("compiler/diameter_dict_parser.yrl", 104).
 yeccpars2_111_(__Stack0) ->
- [__2,__1 | __Stack] = __Stack0,
+ [___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 | __2 ]
+                                  [___1 | ___2]
   end | __Stack].
 
 -compile({inline,yeccpars2_112_/1}).
 -file("compiler/diameter_dict_parser.yrl", 106).
 yeccpars2_112_(__Stack0) ->
- [__2,__1 | __Stack] = __Stack0,
+ [___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 , __2 ]
+                           [___1, ___2]
   end | __Stack].
 
 -compile({inline,yeccpars2_113_/1}).
 -file("compiler/diameter_dict_parser.yrl", 103).
 yeccpars2_113_(__Stack0) ->
  [begin
-   [ ]
+                                  []
   end | __Stack0].
 
 -compile({inline,yeccpars2_114_/1}).
 -file("compiler/diameter_dict_parser.yrl", 63).
 yeccpars2_114_(__Stack0) ->
- [__3,__2,__1 | __Stack] = __Stack0,
+ [___3,___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 , __2 | __3 ]
+                                    [___1, ___2 | ___3]
   end | __Stack].
 
 -compile({inline,yeccpars2_115_/1}).
 -file("compiler/diameter_dict_parser.yrl", 78).
 yeccpars2_115_(__Stack0) ->
  [begin
-   [ ]
+                         []
   end | __Stack0].
 
 -compile({inline,yeccpars2_116_/1}).
 -file("compiler/diameter_dict_parser.yrl", 58).
 yeccpars2_116_(__Stack0) ->
- [__3,__2,__1 | __Stack] = __Stack0,
+ [___3,___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 , __2 | __3 ]
+                                            [___1, ___2 | ___3]
   end | __Stack].
 
 -compile({inline,yeccpars2_117_/1}).
 -file("compiler/diameter_dict_parser.yrl", 78).
 yeccpars2_117_(__Stack0) ->
  [begin
-   [ ]
+                         []
   end | __Stack0].
 
 -compile({inline,yeccpars2_118_/1}).
 -file("compiler/diameter_dict_parser.yrl", 59).
 yeccpars2_118_(__Stack0) ->
- [__3,__2,__1 | __Stack] = __Stack0,
+ [___3,___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 , __2 | __3 ]
+                                          [___1, ___2 | ___3]
   end | __Stack].
 
 -compile({inline,yeccpars2_119_/1}).
 -file("compiler/diameter_dict_parser.yrl", 78).
 yeccpars2_119_(__Stack0) ->
  [begin
-   [ ]
+                         []
   end | __Stack0].
 
 -compile({inline,yeccpars2_120_/1}).
 -file("compiler/diameter_dict_parser.yrl", 57).
 yeccpars2_120_(__Stack0) ->
- [__3,__2,__1 | __Stack] = __Stack0,
+ [___3,___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 , __2 | __3 ]
+                                            [___1, ___2 | ___3]
   end | __Stack].
 
 -compile({inline,yeccpars2_122_/1}).
 -file("compiler/diameter_dict_parser.yrl", 56).
 yeccpars2_122_(__Stack0) ->
- [__2,__1 | __Stack] = __Stack0,
+ [___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 | __2 ]
+                                       [___1 | ___2]
   end | __Stack].
 
 -compile({inline,yeccpars2_123_/1}).
 -file("compiler/diameter_dict_parser.yrl", 71).
 yeccpars2_123_(__Stack0) ->
  [begin
-   [ ]
+                               []
   end | __Stack0].
 
 -compile({inline,yeccpars2_124_/1}).
 -file("compiler/diameter_dict_parser.yrl", 72).
 yeccpars2_124_(__Stack0) ->
- [__2,__1 | __Stack] = __Stack0,
+ [___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 | __2 ]
+                               [___1 | ___2]
+  end | __Stack].
+
+-compile({inline,yeccpars2_126_/1}).
+-file("compiler/diameter_dict_parser.yrl", 76).
+yeccpars2_126_(__Stack0) ->
+ [___1 | __Stack] = __Stack0,
+ [begin
+                    ___1
+  end | __Stack].
+
+-compile({inline,yeccpars2_128_/1}).
+-file("compiler/diameter_dict_parser.yrl", 84).
+yeccpars2_128_(__Stack0) ->
+ [___1 | __Stack] = __Stack0,
+ [begin
+                    
+    ___1
   end | __Stack].
 
 -compile({inline,yeccpars2_129_/1}).
 -file("compiler/diameter_dict_parser.yrl", 74).
 yeccpars2_129_(__Stack0) ->
- [__4,__3,__2,__1 | __Stack] = __Stack0,
+ [___4,___3,___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 , __2 , __3 , __4 ]
+                                             [___1, ___2, ___3, ___4]
   end | __Stack].
 
 -compile({inline,yeccpars2_130_/1}).
--file("compiler/diameter_dict_parser.yrl", 82).
+-file("compiler/diameter_dict_parser.yrl", 81).
 yeccpars2_130_(__Stack0) ->
- [__1 | __Stack] = __Stack0,
+ [___1 | __Stack] = __Stack0,
  [begin
-   { _ , Lineno } = __1 ,
-    { word , Lineno , "" }
+                    
+    {_, Lineno} = ___1,
+    {word, Lineno, ""}
   end | __Stack].
 
 -compile({inline,yeccpars2_131_/1}).
 -file("compiler/diameter_dict_parser.yrl", 49).
 yeccpars2_131_(__Stack0) ->
- [__2,__1 | __Stack] = __Stack0,
+ [___2,___1 | __Stack] = __Stack0,
  [begin
-   [ __1 | __2 ]
+                               [___1 | ___2]
   end | __Stack].
 
 
